@@ -70,9 +70,9 @@ class usepackage(PackageLoader):
         catcode = self.ownerDocument.context.whichCode('&')
         self.ownerDocument.context.catcode('&', Token.CC_LETTER)
         a = self.parse(tex)
+        self.ownerDocument.context.catcode('&', catcode)
         for file in a['names']:
             self.load(tex, file, a['options'])
-        self.ownerDocument.context.catcode('&', catcode)
 
 class RequirePackage(usepackage):
     pass
@@ -155,7 +155,7 @@ class maketitle(Command):
     blockType = True
 
 class title(Command):
-    args = 'self'
+    args = '[ toc ] self'
     def invoke(self, tex):
         Command.invoke(self, tex)
         if not self.ownerDocument.userdata.has_key('title'):
@@ -165,7 +165,10 @@ class author(Command):
     args = 'self'
     def invoke(self, tex):
         Command.invoke(self, tex)
-        self.ownerDocument.userdata['author'] = self
+        userdata = self.ownerDocument.userdata
+        if userdata.get('author') is None:
+            userdata['author'] = []
+        userdata['author'].append(self)
 
 class date(Command):
     args = 'self'
