@@ -546,8 +546,12 @@ def xmlstr(obj):
     """ Escape special characters to create a legal xml string """
     if isinstance(obj, basestring):
         return obj.replace('&','&amp;').replace('<','&lt;').replace('>','&gt;')
+    elif isinstance(obj, list):
+        return unicode([xmlstr(x) for x in obj])
+    elif isinstance(obj, dict):
+        return unicode(dict([(xmlstr(x),xmlstr(y)) for x,y in obj.items()]))
     else:
-        return xmlstr(str(obj))
+        return xmlstr(unicode(obj))
 
 class Node(object):
     """
@@ -606,7 +610,7 @@ class Node(object):
     NODE_SLOTS = ['parentNode','contextDepth','ownerDocument',
                   '_dom_childNodes','_dom_userdata']
     ELEMENT_SLOTS = NODE_SLOTS + ['_dom_attributes','nodeName']
-    TEXT_SLOTS = ['parentNode','contextDepth','ownerDocument']
+    TEXT_SLOTS = ['parentNode','contextDepth','ownerDocument','isMarkup']
 
     __slots__ = []
 
@@ -694,6 +698,9 @@ class Node(object):
         if debug:
             extra = ' parentNode="%s" ownerDocument="%s"' % \
                     (id(self.parentNode), id(self.ownerDocument))
+            
+        if not self.parentNode:
+            extra += ' xmlns:plastex="http://plastex.sf.net/"' 
 
         # Bail out early if the element is empty
         if not(self.attributes) and not(self.hasChildNodes()):
@@ -878,7 +885,7 @@ class Node(object):
         try: return self.childNodes.pop(index)
         except: raise IndexError, 'object has no childNodes'
 
-    def append(self, newChild):
+    def append(self, newChild, setParent=True):
         """ 
         Append `newChild` to child list 
 
@@ -893,19 +900,20 @@ class Node(object):
             newChild = self.ownerDocument.createTextNode(newChild)
         if newChild.nodeType == Node.DOCUMENT_FRAGMENT_NODE:
             for item in newChild:
-                self.append(item)
+                self.append(item, setParent=setParent)
         else:
             self.childNodes.append(newChild) 
-        if self.nodeType == self.DOCUMENT_FRAGMENT_NODE:
-            newChild.parentNode = self.parentNode
-        else:
-            newChild.parentNode = self
+        if setParent:
+            if self.nodeType == self.DOCUMENT_FRAGMENT_NODE:
+                newChild.parentNode = self.parentNode
+            else:
+                newChild.parentNode = self
         newChild.ownerDocument = self.ownerDocument
         return newChild
 
     appendChild = append
 
-    def insert(self, i, newChild):
+    def insert(self, i, newChild, setParent=True):
         """ 
         Insert `newChild` into child list at position `i` 
 
@@ -921,14 +929,15 @@ class Node(object):
             newChild = self.ownerDocument.createTextNode(newChild)
         if newChild.nodeType == Node.DOCUMENT_FRAGMENT_NODE:
             for item in newChild:
-                self.insert(i, item)
+                self.insert(i, item, setParent=setParent)
                 i += 1
         else:
             self.childNodes.insert(i, newChild)
-        if self.nodeType == self.DOCUMENT_FRAGMENT_NODE:
-            newChild.parentNode = self.parentNode
-        else:
-            newChild.parentNode = self
+        if setParent:
+            if self.nodeType == self.DOCUMENT_FRAGMENT_NODE:
+                newChild.parentNode = self.parentNode
+            else:
+                newChild.parentNode = self
         newChild.ownerDocument = self.ownerDocument
         return newChild
 
@@ -956,15 +965,15 @@ class Node(object):
             self.insert(i, node)
             self.pop(i+1)
 
-    def extend(self, other):
+    def extend(self, other, setParent=True):
         """ self += other """
         for item in other:
-            self.append(item)
+            self.append(item, setParent=setParent)
         return self
 
     __iadd__ = extend
 
-    def appendText(self, text, charsubs=[]):
+    def appendText(self, text, charsubs=[], setParent=True):
         """ Append a list of text nodes as one node """
         if not text:
             return
@@ -973,7 +982,8 @@ class Node(object):
             value = value.replace(src, dest)
         text[:] = []
         value = self.ownerDocument.createTextNode(value)
-        value.parentNode = self
+        if setParent:
+            value.parentNode = self
         value.ownerDocument = self.ownerDocument
         self.appendChild(value)
 
