@@ -1,14 +1,19 @@
 #!/usr/bin/env python
 
-import os, time, tempfile, shutil, re, string, pickle, md5, codecs
+import os, time, tempfile, shutil, re, string, pickle, codecs
+try: from hashlib import md5
+except ImportError: from md5 import new as md5
 from plasTeX.Logging import getLogger
 from StringIO import StringIO
 from plasTeX.Filenames import Filenames
 from plasTeX.dictutils import ordereddict
+import subprocess
+import shlex
 
 log = getLogger()
 depthlog = getLogger('render.images.depth')
 status = getLogger('status')
+imagelog = getLogger('imager')
 
 try:
     import Image as PILImage
@@ -77,9 +82,9 @@ def autoCrop(im, bgcolor=None, margin=0):
             bbox[2] += margin
             bbox[3] += margin
             bbox = tuple([max(0,x) for x in bbox])
-        return im.crop(bbox), tuple([abs(x-y) for x,y in zip(origbbox,bbox)])
-    return PILImage.new("RGB", (1,1), bgcolor), (0,0,0,0)
-    return None, None # no contents
+        return im.crop(bbox), tuple([abs(x-y) for x,y in zip(origbbox,bbox)]), bgcolor
+    return PILImage.new("RGB", (1,1), bgcolor), (0,0,0,0), bgcolor
+    return None, None, bgcolor # no contents
 
 class Box(object):
     pass
@@ -319,10 +324,9 @@ class Image(object):
             im = im.convert("RGB")
 
         depth = 0
-        background = im.getpixel((0,0))
 
         # Crop the image so that the regitration mark is on the left edge
-        im = self._autoCrop(im)[0]
+        im, box, background = self._autoCrop(im)
 
         width, height = im.size
         
@@ -392,7 +396,7 @@ class Image(object):
             bbox[0] = rwidth
 
         # Crop out register mark, and autoCrop result    
-        im, cropped = self._autoCrop(im.crop(bbox), background)
+        im, cropped, background = self._autoCrop(im.crop(bbox), background)
 
         # If the content was entirely above the baseline, 
         # we need to keep that whitespace
@@ -506,7 +510,7 @@ class Imager(object):
         self.source.write('\\@ifundefined{plasTeXimage}{'
                           '\\newenvironment{plasTeXimage}[1]{' +
                           '\\vfil\\break\\plasTeXregister' +
-                          '\\thispagestyle{empty}\\def\\@eqnnum{}' +
+                          '\\thispagestyle{empty}\\def\\@eqnnum{}\\def\\tagform@{\\@gobble}' +
                           '\\ignorespaces}{}}{}\n')
         self.source.write('\\@ifundefined{plasTeXregister}{' +
                           '\\def\\plasTeXregister{\\parindent=-0.5in\\ifhmode\\hrule' +
@@ -551,7 +555,7 @@ class Imager(object):
 
         for value in self._cache.values():
             if value.checksum and os.path.isfile(value.path):
-                 d = md5.new(open(value.path,'r').read()).digest()
+                 d = md5(open(value.path,'r').read()).digest()
                  if value.checksum != d:
                      log.warning('The image data for "%s" on the disk has changed.  You may want to clear the image cache.' % value.filename)
 
@@ -573,7 +577,7 @@ class Imager(object):
 
         for value in self._cache.values():
             if value.checksum is None and os.path.isfile(value.path):
-                 value.checksum = md5.new(open(value.path,'r').read()).digest()
+                 value.checksum = md5(open(value.path,'r').read()).digest()
 
         if not os.path.isdir(os.path.dirname(self._filecache)):
             os.makedirs(os.path.dirname(self._filecache))
@@ -610,7 +614,19 @@ class Imager(object):
         program = self.config['images']['compiler']
         if not program:
             program = self.compiler
-        os.system(r"%s %s" % (program, filename))
+
+        cmd = r'%s %s' % (program, filename)
+        p = subprocess.Popen(shlex.split(cmd),
+                     stdout=subprocess.PIPE,
+                     stderr=subprocess.STDOUT,
+                     )
+        while True:
+            line = p.stdout.readline()
+            done = p.poll()
+            if line:
+                imagelog.info(str(line.strip()))        
+            elif done is not None:
+                break
 
         output = None
         for ext in ['.dvi','.pdf','.ps']:
@@ -645,7 +661,21 @@ class Imager(object):
                 if ' ' in value:
                     value = '"%s"' % value
                 options += '%s %s ' % (opt, value)
-        return os.system('%s %s%s' % (self.command, options, 'images.out')), None
+
+        cmd = r'%s %s%s' % (self.command, options, 'images.out')
+        p = subprocess.Popen(shlex.split(cmd),
+                             stdout=subprocess.PIPE,
+                             stderr=subprocess.STDOUT,
+                           )
+        done = None
+        while True:
+            line = p.stdout.readline()
+            done = p.poll()
+            if line:
+                imagelog.info(str(line.strip()))        
+            elif done is not None:
+                break
+        return done, None
 
     def convert(self, output):
         """
@@ -682,8 +712,8 @@ class Imager(object):
         # Sort by creation date
         #images.sort(lambda a,b: cmp(os.stat(a)[9], os.stat(b)[9]))
 
-        images.sort(lambda a,b: cmp(int(re.search(r'^img(\d+)',a).group(1)), 
-                                    int(re.search(r'^img(\d+)',b).group(1))))
+        images.sort(lambda a,b: cmp(int(re.search(r'(\d+)\.\w+$',a).group(1)), 
+                                    int(re.search(r'(\d+)\.\w+$',b).group(1))))
 
         os.chdir(cwd)
 
@@ -697,7 +727,10 @@ class Imager(object):
             directory = os.path.dirname(dest.path)
             if directory and not os.path.isdir(directory):
                 os.makedirs(directory)
-            shutil.copy2(os.path.join(tempdir,src), dest.path)
+            try:
+                shutil.copy2(os.path.join(tempdir,src), dest.path)
+            except OSError:
+                shutil.copy(os.path.join(tempdir,src), dest.path)
 
             # Crop the image
             try: 
