@@ -213,7 +213,7 @@ class harvarditem(thebibliography.bibitem):
 
 class NatBibCite(Base.cite):
     """ Base class for all natbib-style cite commands """
-    args = '* [ text ] [ text2 ] keys:list:str'
+    args = '* [ text ] [ text2 ] bibkeys:list:str'
 
     class Connector(str):
         pass
@@ -224,7 +224,7 @@ class NatBibCite(Base.cite):
         opts = PackageOptions
         doc = self.ownerDocument
         b = doc.userdata.getPath('bibliography/bibitems', {})
-        for key in self.attributes['keys']:
+        for key in self.attributes['bibkeys']:
             if key in b:
                 items.append(b[key])
         if bibpunct.punctuation['style'] in 'ns' and \
@@ -305,6 +305,11 @@ class NatBibCite(Base.cite):
         """ Separator for multiple items """
         return bibpunct.punctuation['sep']
 
+    @property
+    def dates(self):
+        """ Separator between author and dates """
+        return bibpunct.punctuation['dates']
+
     @property
     def years(self):
         """ Separator for multiple years """
@@ -552,7 +557,7 @@ class citep(NatBibCite):
                         res.extend(self.capitalize(item.bibcite.attributes[author]))
                     else:            
                         res.extend(item.bibcite.attributes[author])
-                    res.append(self.separator+' ')
+                    res.append(self.dates+' ')
             res.append(self.citeValue(item, text=text))
             if i < (len(self.bibitems)-1):
                 res.append(self.separator+' ')
@@ -619,7 +624,10 @@ class citealt(NatBibCite):
         i = 0
         prevauthor = sameauthor = None
         for i, item in enumerate(self.bibitems):
-            fullauthor = item.bibcite.attributes['fullauthor'].textContent
+            if not item.bibcite.attributes:
+                fullauthor = '???'
+            else:
+                fullauthor = item.bibcite.attributes['fullauthor'].textContent
             sameauthor = (prevauthor == fullauthor)
             prevauthor = fullauthor
             # Author, only print author if it wasn't equal to the last author
@@ -628,7 +636,9 @@ class citealt(NatBibCite):
                 res.append(self.years+' ')
             else:
                 author = self.selectAuthorField(item.attributes['key'], full=full)
-                if i == 0 and capitalize:
+                if not item.bibcite.attributes:
+                    res.extend('???')
+                elif i == 0 and capitalize:
                     res.extend(self.capitalize(item.bibcite.attributes[author]))
                 else:
                     res.extend(item.bibcite.attributes[author])
@@ -686,7 +696,10 @@ class citealp(NatBibCite):
         i = 0
         prevauthor = sameauthor = None
         for i, item in enumerate(self.bibitems):
-            fullauthor = item.bibcite.attributes['fullauthor'].textContent
+            if not item.bibcite.attributes:
+                fullauthor = '???'
+            else:
+                fullauthor = item.bibcite.attributes['fullauthor'].textContent
             sameauthor = (prevauthor == fullauthor)
             prevauthor = fullauthor
             # Author, only print author if it wasn't equal to the last author
@@ -695,7 +708,9 @@ class citealp(NatBibCite):
                 res.append(self.years+' ')
             else:
                 author = self.selectAuthorField(item.attributes['key'], full=full)
-                if i == 0 and capitalize:
+                if not item.bibcite.attributes:
+                    res.extend('???')
+                elif i == 0 and capitalize:
                     res.extend(self.capitalize(item.bibcite.attributes[author]))
                 else:
                     res.extend(item.bibcite.attributes[author])              
@@ -753,7 +768,9 @@ class citeauthor(NatBibCite):
             author = self.selectAuthorField(item.attributes['key'], full=full)
             b = self.ownerDocument.createElement('bibliographyref')
             b.idref['bibitem'] = item
-            if i == 0 and capitalize:
+            if not item.bibcite.attributes:
+                b.append('???')
+            elif i == 0 and capitalize:
                 b.append(self.capitalize(item.bibcite.attributes[author]))
             else:
                 b.append(item.bibcite.attributes[author])
@@ -787,7 +804,10 @@ class citeyear(NatBibCite):
         for i, item in enumerate(self.bibitems):
             b = self.ownerDocument.createElement('bibliographyref')
             b.idref['bibitem'] = item
-            b.append(item.bibcite.attributes['year'])
+            if not item.bibcite.attributes:
+                b.append('???')
+            else:
+                b.append(item.bibcite.attributes['year'])
             res.append(b)
             if i < (len(self.bibitems)-1):
                 res.append(self.separator+' ')
@@ -808,7 +828,10 @@ class citeyearpar(NatBibCite):
         for i, item in enumerate(self.bibitems):
             b = self.ownerDocument.createElement('bibliographyref')
             b.idref['bibitem'] = item
-            b.append(item.bibcite.attributes['year'])
+            if not item.bibcite.attributes:
+                b.append('???')
+            else:
+                b.append(item.bibcite.attributes['year'])
             res.append(b)
             if i < (len(self.bibitems)-1):
                 res.append(self.separator+' ')
@@ -832,17 +855,17 @@ class defcitealias(Base.Command):
         return res
 
 class citetalias(citet):
-    args = 'keys:list:str'
+    args = 'bibkeys:list:str'
     def citation(self):
-        return citet.citation(self, text=defcitealias.aliases.get(self.attributes['keys'][0],''))
+        return citet.citation(self, text=defcitealias.aliases.get(self.attributes['bibkeys'][0],''))
 
 class citepalias(citep):
-    args = 'keys:list:str'
+    args = 'bibkeys:list:str'
     def citation(self):
-        return citep.citation(self, text=defcitealias.aliases.get(self.attributes['keys'][0],''))
+        return citep.citation(self, text=defcitealias.aliases.get(self.attributes['bibkeys'][0],''))
 
 class shortcites(Base.Command):
-    args = 'keys:list:str'
+    args = 'bibkeys:list:str'
 
 class urlstyle(Base.Command):
     pass
