@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
 from plasTeX.Renderers import Renderer as BaseRenderer
-import textwrap, re
+from plasTeX import encoding
+import textwrap, re, string
 
 class TextRenderer(BaseRenderer):
     """ Renderer for plain text documents """
@@ -22,13 +23,15 @@ class TextRenderer(BaseRenderer):
         'hashmark': '#',
         'space': ' ',
         'tilde': 'active::~',
+        'at': '@',
+        'backslash': '\\',
     }
     
     def __init__(self, *args, **kwargs):
         BaseRenderer.__init__(self, *args, **kwargs)
         
         # Load dictionary with methods
-        for key in vars(type(self)):
+        for key in dir(self):
             if key.startswith('do__'):
                 self[self.aliases[key[4:]]] = getattr(self, key)
             elif key.startswith('do_'):
@@ -48,7 +51,7 @@ class TextRenderer(BaseRenderer):
     def default(self, node):
         """ Rendering method for all non-text nodes """
         # Handle characters like \&, \$, \%, etc.
-        if len(node.nodeName) == 1 and node.nodeName not in string.letters:
+        if len(node.nodeName) == 1 and node.nodeName not in encoding.stringletters():
             return self.textDefault(node.nodeName)
             
         # Render child nodes
@@ -129,8 +132,11 @@ class TextRenderer(BaseRenderer):
                     s = getattr(cell, render)().strip()
                 else:
                     s = render(cell).strip()
-                maxlength = max([len(x) for x in s.split('\n')])
-                minlength = min([len(x) for x in s.split() if x.strip()])
+                if s.strip():
+                    maxlength = max([len(x) for x in s.split('\n')])
+                    minlength = min([len(x) for x in s.split() if x.strip()])
+                else:
+                    minlength = maxlength = 0
                 if r == 0:
                     colwidths.append([minlength, maxlength])
                 else:
@@ -402,15 +408,25 @@ class TextRenderer(BaseRenderer):
         return s
 
     def do__superscript(self, node):
-        return self.default(self, node)
+        return self.default(node)
     
     def do__subscript(self, node):
-        return self.default(self, node)
+        return self.default(node)
     
     # Quotations
     
     def do_quote(self, node):
-        return self.center(self, node)
+        backslash = self['\\']
+        self['\\'] = lambda *args: u'\001'
+        res = [x.strip() for x in unicode(node).split(u'\001')]
+        output = []
+        for par in [x.strip() for x in unicode(node).split(u'\n\n')]:
+            for item in [x.strip() for x in par.split(u'\001')]:
+                output.append(self.fill(item, initial_indent='   ', subsequent_indent='      '))
+            output.append('')
+        output.pop()
+        self['\\'] = backslash
+        return u'\n'.join(output)
     
     do_quotation = do_verse = do_quote
 
@@ -427,11 +443,21 @@ class TextRenderer(BaseRenderer):
         output = []
         metadata = node.ownerDocument.userdata
         if 'title' in metadata:
-            output.append(self.center(metadata['title']).rstrip())
+            output.append(self.center(metadata['title']).rstrip().upper())
+            output.append('')
         if 'author' in metadata:
-            output.append(self.center(metadata['author']).rstrip())
+            for author in metadata['author']:
+                if [a for a in author if getattr(a,'macroName','') == '\\']:
+                    for a in author:
+                        if getattr(a,'macroName','') == '\\':
+                            continue
+                        output.append(self.center(a).rstrip())
+                else:
+                    output.append(self.center(author).rstrip())
+            output.append('')
         if 'date' in metadata:
             output.append(self.center(metadata['date']).rstrip())
+            output.append('')
         if 'thanks' in metadata:
             output.append(self.center(metadata['thanks']).rstrip())
         return u'\n%s\n\n' % u'\n'.join(output)
@@ -512,7 +538,7 @@ class TextRenderer(BaseRenderer):
         return u''
         
     do_bigskip = do_medskip = do_smallskip = do_vspace
-    
+
     # Tabbing - not implemented yet
     
     # Verbatim
@@ -522,4 +548,13 @@ class TextRenderer(BaseRenderer):
 
     do_alltt = do_verbatim
 
+    def do_mbox(self, node):
+        return self.default(node)
+
+    def do__at(self, node):
+        return u''
+
+    def do__backslash(self, node):
+        return u'\\'
+
 Renderer = TextRenderer
