@@ -1,9 +1,11 @@
 #!/usr/bin/env python
 
+__version__ = '9.3'
+
 import string, re
 from DOM import Element, Text, Node, DocumentFragment, Document
 from Tokenizer import Token, BeginGroup, EndGroup, Other
-from plasTeX import Logging
+from plasTeX import Logging, encoding
 
 log = Logging.getLogger()
 status = Logging.getLogger('status')
@@ -50,7 +52,7 @@ def ismacro(o):
 
 def issection(o): 
     """ Is the given object a section? """
-    return o.level >= Node.DOCUMENT_LEVEL and o.level < Node.END_SECTIONS_LEVEL 
+    return o.level >= Node.DOCUMENT_LEVEL and o.level < Node.ENDSECTIONS_LEVEL 
 
 def macroName(o):
      """ Return the macro name of the given object """
@@ -226,7 +228,7 @@ class Macro(Element):
             except AttributeError:
                 if self.ref is not None:
                     fullTitle = self.ownerDocument.createDocumentFragment()
-                    fullTitle.extend([self.ref, ' ', self.title])
+                    fullTitle.extend([self.ref, ' ', self.title], setParent=False)
                 else:
                     fullTitle = self.title
                 setattr(self, '@fullTitle', fullTitle)
@@ -266,7 +268,7 @@ class Macro(Element):
                 except AttributeError:
                     if self.ref is not None:
                         fullTocEntry = self.ownerDocument.createDocumentFragment()
-                        fullTocEntry.extend([self.ref, ' ', self.tocEntry])
+                        fullTocEntry.extend([self.ref, ' ', self.tocEntry], setParent=False)
                     else:
                         fullTocEntry = self.tocEntry
                     setattr(self, '@fullTocEntry', fullTocEntry)
@@ -427,7 +429,7 @@ class Macro(Element):
         argSource = sourceArguments(self)
         if not argSource:
             argSource = ' '
-        elif argSource[0] in string.letters:
+        elif argSource[0] in encoding.stringletters():
             argSource = ' %s' % argSource
         s = '%s%s%s' % (escape, name, argSource)
 
@@ -439,6 +441,10 @@ class Macro(Element):
                 s += sourceChildren(self)
         return s
 
+    @property
+    def childrenSource(self):
+        return sourceChildren(self)
+
     def parse(self, tex): 
         """ 
         Parse the arguments defined in the `args` variable 
@@ -627,7 +633,7 @@ class Macro(Element):
                 pass
 
             # Argument name (and possibly type)
-            elif item[0] in string.letters:
+            elif item[0] in encoding.stringletters():
                 parts = item.split(':')
                 item = parts.pop(0)
                 # Parse for types and subtypes
@@ -789,6 +795,8 @@ class TeXDocument(Document):
     charsubs = [
         ('``', unichr(8220)),
         ("''", unichr(8221)),
+        ('"`', unichr(8222)),
+        ('"\'', unichr(8220)),
         ('`',  unichr(8216)),
         ("'",  unichr(8217)),
         ('---',unichr(8212)),
@@ -804,7 +812,7 @@ class TeXDocument(Document):
     ]
 
     def __init__(self, *args, **kwargs):
-        Document.__init__(self, *args, **kwargs)
+        #super(TeXDocument, self).__init__(*args, **kwargs)
 
         if 'context' not in kwargs:
             import Context
@@ -938,7 +946,8 @@ class NewIf(Macro):
     state = False
 
     def invoke(self, tex):
-        return tex.readIfContent(type(self).state)
+        tex.processIfContent(type(self).state)
+        return []
 
     @classmethod
     def setState(cls, state):
@@ -1049,7 +1058,7 @@ class Definition(Macro):
 
             # Beginning a new parameter
             if a.catcode == Token.CC_PARAMETER:
-
+                
                 # Adjacent parameters, just get the next token
                 if inparam:
                     params.append(tex.readArgument(parentNode=self,
@@ -1061,6 +1070,9 @@ class Definition(Macro):
                     if a in string.digits:
                         inparam = True
 
+                    elif a.catcode == Token.CC_PARAMETER:
+                        continue
+                    
                     # Handle #{ case here
                     elif a.catcode == Token.CC_BGROUP:
                         param = []
@@ -1127,11 +1139,11 @@ class dimen(float):
     def __new__(cls, v):
         if isinstance(v, Macro):
             return v.__dimen__()
-        elif isinstance(v, basestring) and v[-1] in string.letters:
+        elif isinstance(v, basestring) and v[-1] in encoding.stringletters():
             # Get rid of glue components
             v = list(v.split('plus').pop(0).split('minus').pop(0).strip())
             units = []
-            while v and v[-1] in string.letters:
+            while v and v[-1] in encoding.stringletters():
                 units.insert(0, v.pop())
             v = float(''.join(v))
             units = ''.join(units) 
@@ -1272,7 +1284,7 @@ class glue(dimen):
         return dimen.__new__(cls, g)
         
     def __init__(self, g, plus=None, minus=None):
-        dimen.__init__(self, g)
+        #super(glue, self).__init__(g)
         self.stretch = self.shrink = None
         if plus is not None:
             self.stretch = dimen(plus)
@@ -1491,7 +1503,7 @@ class Counter(object):
 
     @property
     def Alph(self):
-        return string.letters[self.value-1].upper()
+        return encoding.stringletters()[self.value-1].upper()
 
     @property
     def alph(self):
@@ -1514,7 +1526,7 @@ class TheCounter(Command):
 
             # If there is a reference to another \\thecounter, invoke it
             if name.startswith('the'):
-                return u''.join(self.ownerDocument.createElement(name).invoke(tex))
+                return u''.join(tex.expandTokens(self.ownerDocument.createElement(name).invoke(tex)))
 
             # Get formatted value of the requested counter
             format = m.group(2)
